@@ -441,7 +441,7 @@ def get_dict_properties(item, fields, mixed_case_fields=None, formatters=None):
         data = item[field_name] if field_name in item else ''
         if field in formatters:
             formatter = formatters[field]
-            if (isinstance(formatter, type) and isinstance(
+            if (isinstance(formatter, type) and issubclass(
                     formatter, cliff_columns.FormattableColumn)):
                 data = formatter(data)
             elif callable(formatter):
@@ -508,7 +508,7 @@ def get_item_properties(item, fields, mixed_case_fields=None, formatters=None):
         data = getattr(item, field_name, '')
         if field in formatters:
             formatter = formatters[field]
-            if (isinstance(formatter, type) and isinstance(
+            if (isinstance(formatter, type) and issubclass(
                     formatter, cliff_columns.FormattableColumn)):
                 data = formatter(data)
             elif callable(formatter):
